@@ -37,6 +37,10 @@ class Lab:
 
     Lab contains the labml specific properties.
     """
+    experiments: Optional[Path]
+    data_path: Optional[Path]
+    check_repo_dirty: Optional[bool]
+    path: Optional[Path]
     web_api: Optional[WebAPIConfigs]
 
     def __init__(self):
@@ -88,16 +92,16 @@ class Lab:
             self.experiments = None
             self.data_path = None
         else:
-            self.path = PurePath(self.configs['path'])
-            self.data_path = self.path / self.configs['data_path']
-            self.experiments = self.path / self.configs['experiments_path']
+            self.path = Path(self.configs['path'])
+            self.data_path = (self.path / self.configs['data_path']).resolve()
+            self.experiments = (self.path / self.configs['experiments_path']).resolve()
 
         self.check_repo_dirty = self.configs['check_repo_dirty']
         self.indicators = self.configs['indicators']
         if self.configs['web_api']:
             web_api_url = self.configs['web_api']
             if web_api_url[0:4] != 'http':
-                web_api_url = f"https://api.lab-ml.com/api/v1/track?labml_token={web_api_url}"
+                web_api_url = f"https://api.lab-ml.com/api/v1/track?labml_token={web_api_url}&"
             self.web_api = WebAPIConfigs(url=web_api_url,
                                          frequency=self.configs['web_api_frequency'],
                                          verify_connection=self.configs['web_api_verify_connection'],
@@ -127,7 +131,7 @@ class Lab:
             experiments_path='logs',
             analytics_path='analytics',
             analytics_templates={},
-            web_api='https://api.lab-ml.com/api/v1/track',
+            web_api='https://api.lab-ml.com/api/v1/track?',
             web_api_frequency=60,
             web_api_verify_connection=True,
             web_api_open_browser=True,
@@ -147,6 +151,10 @@ class Lab:
                 'class_name': 'Scalar',
                 'is_print': False,
                 'name': 'module.*'
+            }, {
+                'class_name': 'Scalar',
+                'is_print': False,
+                'name': 'optim.*'
             }, {
                 'class_name': 'Scalar',
                 'is_print': False,
