@@ -1,4 +1,10 @@
 """
+---
+title: Proximal Policy Optimization (PPO)
+summary: >
+ An annotated implementation of Proximal Policy Optimization (PPO) algorithm in PyTorch.
+---
+
 # Proximal Policy Optimization (PPO)
 
 This is a an implementation of [Proximal Policy Optimization - PPO](https://arxiv.org/abs/1707.06347).
